﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DataGridTableRelations
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        DataSet _ds;

        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            CreateTables();

            CreateFieldLayouts();

            dataGrid1.DataSource = _ds.Tables[0].DefaultView;
        }

        private void CreateTables()
        {
            _ds = new DataSet();
            DataTable dataTable = new DataTable("parentTable");
            dataTable.Columns.Add("ID", typeof(int));
            dataTable.Columns.Add("Select", typeof(bool));
            dataTable.Columns.Add("Groups", typeof(string));
            dataTable.Columns.Add("Permissions", typeof(string));

            dataTable.Rows.Add(0, false, "name", "rights");
            dataTable.Rows.Add(1, false, "name", "rights");
            dataTable.Rows.Add(2, false, "name", "rights");
            dataTable.Rows.Add(3, false, "name", "rights");
            dataTable.Rows.Add(4, false, "name", "rights");
            dataTable.Rows.Add(5, false, "name", "rights");
            dataTable.Rows.Add(6, false, "name", "rights");

            DataTable childTable1 = new DataTable("childTable1");
            childTable1.Columns.Add("parentID", typeof(int));
            childTable1.Columns.Add("col1", typeof(string));
            childTable1.Columns.Add("col2", typeof(string));
            childTable1.Columns.Add("col3", typeof(string));

            childTable1.Rows.Add(0, "child 1", "child 1", "child 1");
            childTable1.Rows.Add(0, "child 1", "child 1", "child 1");
            childTable1.Rows.Add(1, "child 1", "child 1", "child 1");

            DataTable childTable2 = new DataTable("childTable2");
            childTable2.Columns.Add("parentID", typeof(int));
            childTable2.Columns.Add("col1", typeof(string));
            childTable2.Columns.Add("col2", typeof(string));
            childTable2.Columns.Add("col3", typeof(string));

            childTable2.Rows.Add(0, "child 2", "child 2", "child 2");
            childTable2.Rows.Add(0, "child 2", "child 2", "child 2");
            childTable2.Rows.Add(1, "child 2", "child 2", "child 2");

            _ds.Tables.Add(dataTable);
            _ds.Tables.Add(childTable1);
            _ds.Tables.Add(childTable2);

            DataRelation relation1 = new DataRelation("ChildRelation1", dataTable.Columns[0], childTable1.Columns[0]);
            _ds.Relations.Add(relation1);
            DataRelation relation2 = new DataRelation("ChildRelation2", dataTable.Columns[0], childTable2.Columns[0]);
            _ds.Relations.Add(relation2);
        }

        private void CreateFieldLayouts()
        {
            dataGrid1.FieldLayoutSettings.AutoGenerateFields = false;

            FieldLayout layout1 = new FieldLayout() { Key = "parentTable", KeyMatchingEnforced = true, };
            layout1.Fields.Add(new Field { Name = "ID" });
            layout1.Fields.Add(new CheckBoxField { Name = "Select" });
            layout1.Fields.Add(new TextField { Name = "Groups" });
            layout1.Fields.Add(new TextField { Name = "Permissions" });
            layout1.Fields.Add(new Field { Name = "ChildRelation1" }); // this field allows for childTable1 to appear
            layout1.Fields.Add(new Field { Name = "ChildRelation2" }); // this field allows for childTable2 to appear
            dataGrid1.FieldLayouts.Add(layout1);

            FieldLayout layout2 = new FieldLayout() { Key = "ChildRelation1", KeyMatchingEnforced = true, };
            layout2.Fields.Add(new Field { Name = "parentID" });
            layout2.Fields.Add(new TextField { Name = "col1" });
            layout2.Fields.Add(new TextField { Name = "col2" });
            layout2.Fields.Add(new TextField { Name = "col3" });
            dataGrid1.FieldLayouts.Add(layout2);

            FieldLayout layout3 = new FieldLayout() { Key = "ChildRelation2", KeyMatchingEnforced = true, };
            layout3.Fields.Add(new Field { Name = "parentID" });
            layout3.Fields.Add(new TextField { Name = "col1" });
            layout3.Fields.Add(new TextField { Name = "col2" });
            layout3.Fields.Add(new TextField { Name = "col3" });
            dataGrid1.FieldLayouts.Add(layout3);

            // If I set the visibility on one of the child relation fields, it will keep the children from showing but it will
            // still show the ExpandableFieldRecordPresenter for the visible relation.  This is because the FieldLayout contains
            // multiple relation fields.
            //layout1.Fields["ChildRelation1"].Visibility = System.Windows.Visibility.Collapsed;

            // If you do not want the ExpandableFieldRecordPresenter to show at all then you will need to remove all relations from
            // the FieldLayout and just leave the one you want
            //layout1.Fields.Remove(layout1.Fields["ChildRelation1"]);
        }
    }
}
